## [0.2.0] - 2021-09-09

- Add option to connect with Soda cloud

## [0.1.1] - 2021-09-07

- Update documentation:
  - Add example for executing a scan with file
  - Explain how the `soda-spark` works
- Add change log

## [0.1.0] - 2021-09-06

- Implement Soda scan execute functionality
